make_run_config: Generates and use a config txt file
Description
When this function run the first time, it will generated a config.txt file in the user working directory.
It will import the data config file into the use environment. This data will be used to change the column names
of the imported dataset and change the name of the markers that is often incorrectly exported.